netapp_ontap.models.lun_status API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.lun_status`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class LunStatusSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the LunStatus object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `container_state: str GET`

    The state of the volume and aggregate that contain the LUN. LUNs are only available when their containers are available.

    Valid choices:

    - online
    - aggregate_offline
    - volume_offline
  `mapped: bool GET`

    Reports if the LUN is mapped to one or more initiator groups.
    There is an added computational cost to retrieving this property's value. It is not populated for a GET request unless it is explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more.

  `read_only: bool GET`

    Reports if the LUN allows only read access.

  `state: str GET`

    The state of the LUN. Normal states for a LUN are online and offline. Other states indicate errors.

    Valid choices:

    - foreign_lun_error
    - nvfail
    - offline
    - online
    - space_error